{% extends "base.html" %}

{% block body %}

    <div align="center">
        <h3>An error has occurred:</h3>
        <p>{{ errorMessage }}</p>
    </div>

    <!--div align="center">
      <h3>An error has occurred: Error {{ errorTitle }}.</h3>
      <p>{{ errorMessage }}</p>
  </div-->

{% endblock %}

{% block more_scripts %}
{% endblock %}