<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="EDAM">
    <meta name="keywords" content="EDAM,SOS,OGC">
    <meta name="author" content="Ioannis Athanasiadis">
    <meta name="author" content="Argyrios Samourkasidis">
    {% block head %}{% endblock %}
    <title>{% block title %}{% endblock %}</title>

    <!-- Bootstrap core CSS -->
    <link href="{{ url_for('static', filename='css/bootstrap.css') }}" rel="stylesheet" media="screen">
    <link href="{{ url_for('static', filename='css/app.css') }}" rel="stylesheet" media="screen">
    <link rel="shortcut icon" href="{{ url_for('static', filename='img/favicon.ico') }}"/>

    <script type="text/javascript"
            href="http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js"></script>
</head>

<body>
 {% set navigation_bar = [
        ('/maps/', 'maps', 'Maps'),
        ('/about/', 'about', 'API'),
        ('/SensorObservationService/', 'sos', 'OGC SOS'),
        ('/home/', 'home', 'Home')] -%}
        {% set active_page = active_page|default('maps') %}

<div class="navbar navbar-static-top">
  <div class="navbar-inner">
      <div class="container">
          <h1 class="text-white brand navbar-header navbar-brand"><a href={{ url_for('mapview') }}> EDAM </a></h1>
    <ul class="nav nav-pills inline-navbar">
        {% for href, id, caption in navigation_bar %}
                    <li{% if id == active_page %} class="active"{% endif %}><a href="{{ href|e }}">{{ caption|e }}</a>
                    </li>
        {% endfor %}
    </ul>
          </div>
  </div>
</div>

<div class="container">
            {% block body %}{% endblock %}
</div>

</body>
</html>
